@@ -3,12 +3,15 @@ from .core import process
 __all__ =\
 [
 	'agile_innovative_blinkstick',
+	'embrava_blynclight',
+	'kuando_busylight',
 	'lifx_light',
+	'luxafor_flag',
 	'magic_hue',
 	'nanoleaf_light',
 	'philips_hue',
 	'razer_chroma',
-	'thingm_blink',
+	'thingm_blink1',
 	'wiz_light',
 	'xiaomi_yeelight'
 ]
