@@ -2,6 +2,7 @@ import socket
 from typing import Any, Dict, List
 from argparse import ArgumentParser
 from chroma_feedback import helper, wording
+from chroma_feedback.typing import StatusType
 from .light import get_lights, process_lights
 
 ARGS = None
@@ -22,7 +23,7 @@ def init(program : ArgumentParser) -> None:
 	ARGS = helper.get_first(program.parse_known_args())
 
 
-def run(status : str) -> List[Dict[str, Any]]:
+def run(status : StatusType) -> List[Dict[str, Any]]:
 	lights = get_lights(ARGS.magic_hue_ip)
 
 	if not lights:
