@@ -2,6 +2,7 @@ from typing import Any, Dict, List
 from argparse import ArgumentParser
 import socket
 from chroma_feedback import helper, wording
+from chroma_feedback.typing import StatusType
 from .group import get_groups, process_groups
 from .light import get_lights, process_lights
 from .api import get_api
@@ -26,7 +27,7 @@ def init(program : ArgumentParser) -> None:
 	ARGS = helper.get_first(program.parse_known_args())
 
 
-def run(status : str) -> List[Dict[str, Any]]:
+def run(status : StatusType) -> List[Dict[str, Any]]:
 	api = get_api(ARGS.philips_hue_ip)
 
 	# use groups
