@@ -1,6 +1,7 @@
 from typing import Any, Dict, List
 from argparse import ArgumentParser
 from chroma_feedback import helper, wording
+from chroma_feedback.typing import StatusType
 from .device import get_devices, process_devices
 from .api import get_api
 
@@ -15,7 +16,7 @@ def init(program : ArgumentParser) -> None:
 	ARGS = helper.get_first(program.parse_known_args())
 
 
-def run(status : str) -> List[Dict[str, Any]]:
+def run(status : StatusType) -> List[Dict[str, Any]]:
 	api = get_api()
 	devices = get_devices(api.devices, ARGS.razer_chroma_device)
 
