@@ -1,10 +1,12 @@
+from chroma_feedback.producer import __all__ as producer
+
 METADATA =\
 {
 	'name': 'chroma-feedback',
 	'description': 'Turn your RGB powered hardware into an build indicator for continuous integration',
-	'version': '8.2.1',
+	'version': '9.1.1',
 	'license': 'MIT',
-	'keywords': 'appveyor bamboo circle codeship github gitlab jenkins teamcity travis',
+	'keywords': ' '.join(producer),
 	'author': 'Henry Ruhs',
 	'author_email': 'info@redaxmedia.com',
 	'url': 'https://github.com/redaxmedia/chroma-feedback'
