@@ -3,8 +3,10 @@ from .core import process
 __all__ =\
 [
 	'appveyor',
+	'azure',
 	'bamboo',
 	'bitbucket',
+	'buddy',
 	'circle',
 	'codeship',
 	'custom',
