@@ -22,7 +22,7 @@ def run() -> List[Dict[str, Any]]:
 	result = []
 
 	for slug in ARGS.bitbucket_slug:
-		result.extend(fetch(ARGS.bitbucket_host, slug, ARGS.bitbucket_username, ARGS.bitbucket_password,))
+		result.extend(fetch(ARGS.bitbucket_host, slug, ARGS.bitbucket_username, ARGS.bitbucket_password))
 	return result
 
 
@@ -45,6 +45,7 @@ def fetch(host : str, slug : str, username : str, password : str) -> List[Dict[s
 
 		if 'values' in data:
 			build = helper.get_first(data['values'])
-			if build:
-				result.append(normalize_data(build))
+
+			if build and 'repository' in build and 'full_name' in build['repository'] and 'state' in build and 'result' in build['state'] and 'name' in build['state']['result']:
+				result.append(normalize_data(build['repository']['full_name'], build['state']['result']['name']))
 	return result
