@@ -1,18 +1,19 @@
 from typing import Any, Dict
 from chroma_feedback import helper
+from chroma_feedback.typing import StatusType
 
 
-def normalize_data(build : Dict[str, Any]) -> Dict[str, Any]:
+def normalize_data(slug : str, status : str) -> Dict[str, Any]:
 	return\
 	{
 		'producer': 'bitbucket',
-		'slug': build['repository']['full_name'],
+		'slug': slug,
 		'active': True,
-		'status': normalize_status(build['state']['result']['name'])
+		'status': normalize_status(status)
 	}
 
 
-def normalize_status(status : str) -> str:
+def normalize_status(status : str) -> StatusType:
 	status = helper.to_lower_case(status)
 
 	if status == 'inprogress':
