@@ -42,6 +42,10 @@ def fetch(host : str, slug : str, token : str) -> List[Dict[str, Any]]:
 
 		if 'id' in data:
 			result.extend(fetch_runs(host, slug, data['id'], token))
+		else:
+			for application in data:
+				if 'id' in application:
+					result.extend(fetch_runs(host, slug, application['id'], token))
 	return result
 
 
@@ -62,7 +66,6 @@ def fetch_runs(host : str, slug : str, application_id : str, token : str) -> Lis
 		data = request.parse_json(response)
 		build = helper.get_first(data)
 
-		if build:
-			build['slug'] = slug
-			result.append(normalize_data(build))
+		if build and 'status' in build and 'result' in build:
+			result.append(normalize_data(slug, build['status'], build['result']))
 	return result
