@@ -1,18 +1,19 @@
 from typing import Any, Dict
 from chroma_feedback import helper
+from chroma_feedback.typing import StatusType
 
 
-def normalize_data(build : Dict[str, Any]) -> Dict[str, Any]:
+def normalize_data(slug : str, status : str, result : str) -> Dict[str, Any]:
 	return\
 	{
 		'producer': 'wercker',
-		'slug': build['slug'],
+		'slug': slug,
 		'active': True,
-		'status': normalize_status(build['status'], build['result'])
+		'status': normalize_status(status, result)
 	}
 
 
-def normalize_status(status : str, result : str) -> str:
+def normalize_status(status : str, result : str) -> StatusType:
 	status = helper.to_lower_case(status)
 	result = helper.to_lower_case(result)
 
