@@ -10,11 +10,11 @@ def get(url : str, headers : Dict[str, str] = None) -> Any:
 		return get(url, headers)
 
 
-def post(url : str, headers : Dict[str, str] = None) -> Any:
+def post(url : str, data : Any = None, headers : Dict[str, str] = None) -> Any:
 	try:
-		return requests.post(url, headers = headers, timeout = 10)
+		return requests.post(url, data, headers = headers, timeout = 10)
 	except RequestException:
-		return post(url, headers)
+		return post(url, data, headers)
 
 
 def parse_json(response: Response) -> Any:
