@@ -8,20 +8,24 @@ WORDING =\
 	'device_no': 'Device not found',
 	'light_no': 'Light not found',
 	'group_no': 'Group not found',
-	'producer_no': 'Producer not found',
-	'consumer_no': 'Consumer not found',
+	'producer_no': 'Producer {} not found',
+	'producer_crash': 'Producer {} crashed',
+	'consumer_no': 'Consumer {} not found',
+	'consumer_crash': 'Consumer {} crashed',
 	'result_no': 'Result not found',
 	'build_passed': 'Build of {} on {} passed',
-	'build_process': 'Build of {} on {} in process',
+	'build_started': 'Build of {} on {} started',
 	'build_errored': 'Build of {} on {} errored',
 	'build_failed': 'Build of {} on {} failed',
 	'setting_passed': 'Setting {} to build passed',
-	'setting_process': 'Setting {} to build in process',
+	'setting_started': 'Setting {} to build started',
 	'setting_errored': 'Setting {} to build errored',
 	'setting_failed': 'Setting {} to build failed',
 	'press_button': 'Press {} button on {}',
 	'enable_feature': 'Enable {} on {}',
 	'goodbye': 'Goodbye',
+	'about': 'About',
+	'exit': 'Exit',
 	'by': 'by',
 	'hourglass': u'\u29d7',
 	'tick': u'\u2714',
